//
//	loop over all instruments and figure out the pixel that has the
//	telescope focus
//
#include <iostream>
#include "CalServer.h"
#include "Xmm.h"
#include "GeometryDataServer.h"
#include "common.h"

using namespace std;

int main()
{
	RightAscension srcRa = RightAscension(0.);
	Declination srcDec = Declination(0.);
	EquatorialDirection src(srcRa, srcDec);

	for (unsigned i=0; i<xmmPayLoad.instruments().size(); ++i) {
		Xmm::Instrument ins = xmmPayLoad.instruments()[i]->id();

		if (ins == Xmm::ERM)
		continue;

		calServer.setInstrument(ins);

		Boresight *bs = 0; bs = calServer.getAtom(bs);
		bs->withSacCoordOrientation(SpacecraftAttitude(0., 0., 0.));

		XmmTelescopePointList tpl = bs->projectOntoTelCoord(src);
		XmmCartesianPointList cpl = tpl.toCamCoord2().toCamCoord1();
		vector<Ccd> ccd = cpl.onCcd();
		XmmPixelList ccl = cpl.toChipCoord();
		std::cout<<"Boresight pixel (CHIPCOORD) of "<<Xmm::toString(ins)<<": ";
		if (ccd[0] == Xmm::CCD_NONE)
			std::cout<<"not an any CCD - either outside FOV or in chip gap";
		else
			std::cout<<ccl.x()[0]<<'/'<<ccl.y()[0]<< "(CCD "<<ccd[0]<<')';
		std::cout<<std::endl;
	}

	return 0;
}
