//
//	test the extraction from the reject CCF
//
//	REFERENCES:
//
//	UL, Thu Sep 30 11:46:13 MET DST 1999
//
#include <cassert>
#include <cmath>
#include <fstream>
#include <iostream>
#include "CalServer.h"
#include "Xmm.h"
#include "GeometryDataServer.h"
#include "LowEnergyNoiseServer.h"
#include "common.h"

bool isClose(real32 a, real32 b)
{
	if (fabs(b) < 5.e-3)
		//	absolute
		return fabs(a) < 5.e-3;
	else
		return fabs(fabs(a)/fabs(b)-1.) < 5.e-3;
}

int main()
{
    cout<<" Getting the server 1"<<endl;

	calServer.setInstrument(Xmm::EPN);
	calServer.state()->mode()->set(Xmm::PRIME_FULL_WINDOW);
	calServer.state()->ccd()->set(4);

	//
	//	Test that the median map is successfully returned for this mode/ccd
	//
	cout<<" Getting the server"<<endl;
    LowEnergyNoiseServer *lens = 0; lens = calServer.getAtom(lens);

	cout<<" Got the server"<<endl;

    const SImage &map = lens->medianMap();
	cout<<" Got the map"<<endl;
    float d34 = map[34][4];
    float d99 = map[50][19];
	cout<<" Median Map(35,5): "<<d34<<" (51,20): "<<d99<<endl;

    const SImage &map2 = lens->masterOffset();
	cout<<" Got the master offset"<<endl;
    d34 = map2[193][0];
    d99 = map2[50][49];
	cout<<" Master offset(194,1): "<<d34<<" (51,50): "<<d99<<endl;

	//
	//	Test that the correction values are being read ok
	//
    const vector<real32> &lowen = lens->lowEnergy();
    const vector<real32> &highen = lens->highEnergy();
    const vector<int16> &corrVal = lens->correctionValue();

	cout<<" Correction values [0]: "<<lowen[0]<<" "<<highen[0]
        <<" "<<corrVal[0]<<endl;

	//
	//	Test that the noise maps are extracted
	//
    const vector<int8> &rawxvector = lens->rawxVector();
    const vector<SImage> &mapvector = lens->noiseMapVector();

    unsigned rx0 = rawxvector[0];
    SImage s = mapvector[0];
    float mapval21 = s[168][17];

	cout<<" Noise map[169,18]: "<<rx0<<" "<<mapval21<<endl;

        //
        //      Test the master offset for the Closed filter
        //
    calServer.setInstrument(Xmm::EPN);
    calServer.state()->mode()->set(Xmm::FAST_TIMING);
    calServer.state()->ccd()->set(4);

        //  REMOVE UNTIL CCF available
       /*
        cout<<" Getting the server"<<endl;
    LowEnergyNoiseServer *lens2 = 0; lens2 = calServer.getAtom(lens2);

    const SImage &map3 = lens2->masterOffsetClosed();
        cout<<" Got the master offset for the closed filter"<<endl;
    d34 = map3[144][21];
    d99 = map3[50][49];
        cout<<" Master offset closed (145,22): "<<d34<<" (51,50): "<<d99<<endl;
    const vector<real32> &xrlc = lens2->xrayLoadCoeff();
        cout<<" Master offset closed Xray Load coeffs: "<<xrlc[0]<<" "
            <<xrlc[1]<<endl;

    // And BURST mode
        cout<<" Getting the server"<<endl;
    calServer.state()->mode()->set(Xmm::FAST_BURST);
    LowEnergyNoiseServer *lens3 = 0; lens3 = calServer.getAtom(lens3);
    const SImage &map4 = lens3->masterOffsetClosed();
    d34 = map4[144][21];
    d99 = map4[50][49];
        cout<<" Master closed BURST (145,22): "<<d34<<" (51,50): "<<d99<<endl;
      */

     
    return 0;
}
