//
//	test RGA-related stuff; embryonic at the moment; add more test in due
//	time
//
#include <iostream>
#include <iomanip>
#include <cmath>
#include "CalCommon.h"
#include "CalServer.h"
#include "GratingDataServer.h"
#include "Xmm.h"

using namespace std;

static bool isClose(double a, double b)
{
    return fabs(a)/fabs(b)-1. < 1.e-5;
}

int main(int argc, char **argv)
{
	if (argc>1)
		calServer.ccf()->registerNewCifEntry(argv[1]);

	const double E = 1100,
				 ALPHA = 2.7*DEG_TO_RAD;
	const int ORDER = -1;

	calServer.setInstrument(Xmm::RGS1);
	GratingDataServer *gds = 0; gds = calServer.getAtom(gds);

	double betaM = gds->beta(ALPHA, ORDER, E),
		   order = gds->order(ALPHA, betaM, E),
		   energy = gds->energy(ALPHA, betaM, ORDER);

	cout<<"order="<<order<<endl;
	cout<<"energy="<<energy<<endl;
	assert(isClose(order, ORDER));
	assert(isClose(energy, E));

	//	misalignment figure distribution
	double chromaticMagnification = 1.;
	const double NBETA = 10000.,
				 DELTA_BETA = .5,	//	beta span
				 binWidth = DELTA_BETA/NBETA;

	Spectrum spec(gds->misalignmentFigureDistribution(7.,
												   binWidth*DEG_TO_RAD,
												   chromaticMagnification));
	int N = spec.size();
	for (int n=0; n<N; ++n)
		cout<<setprecision(6)<<n-N/2<<' '<<spec[n]<<endl;
	return 0;
}

