//
//	test the specQuality access 
//
//	REFERENCES:
//
//	RDS, April 13 2009
//
#include <cmath>
#include <iostream>
#include "CalServer.h"
#include "SpecQualityServer.h"

using namespace std;

int main()
{
	calServer.setInstrument(Xmm::EPN);
	calServer.state()->randomize()->set(false);
	calServer.state()->temperature()->set(293.);
	calServer.state()->temperatureCamera()->set(293);
        //calServer.state()->mode()->set(Xmm::PRIME_FULL_WINDOW);
        calServer.state()->mode()->set(Xmm::FAST_TIMING);

        // Get the server
	SpecQualityServer *ct = 0; ct = calServer.getAtom(ct);

        short ngroups = ct->nGroups();
        vector<short> ranges = ct->ranges();
        cout<<"EPN....."<<endl;
        cout<<"NGRP: "<<ngroups<<" Range[2]: "<<ranges[1]<<endl;

        float gsmin = ct->gainSlopeMin();
        float gsmax = ct->gainSlopeMax();
        float gomin = ct->gainOffsetMin();
        float gomax = ct->gainOffsetMax();

        cout<<"GAIN: "<<gsmin<<" "<<gsmax<<" "<<gomin<<" "<<gomax<<endl;

        calServer.releaseAtom(ct);

        calServer.setInstrument(Xmm::EMOS2);
        calServer.state()->mode()->set(Xmm::FAST_COMPRESSED);

        ct = calServer.getAtom(ct);

        ngroups = ct->nGroups();
        ranges = ct->ranges();
        cout<<"EMOS2....."<<endl;
        cout<<"NGRP: "<<ngroups<<" Range[2]: "<<ranges[1]<<endl;

        gsmin = ct->gainSlopeMin();
        gsmax = ct->gainSlopeMax();
        gomin = ct->gainOffsetMin();
        gomax = ct->gainOffsetMax();

        cout<<"GAIN: "<<gsmin<<" "<<gsmax<<" "<<gomin<<" "<<gomax<<endl;

       // Resolution arrays
        vector<float> res_energy = ct->resolution_energy();
        vector<float> resolution = ct->resolution();

        calServer.releaseAtom(ct);
        calServer.setInstrument(Xmm::EPN);
        calServer.state()->mode()->set(Xmm::FAST_TIMING);
        ct = calServer.getAtom(ct);
        cout<<"EPN Resolution: "<< res_energy[0]<<" "<<resolution[0]
            <<" "<<res_energy[1000]<<" "<<resolution[1000]<<endl;

        calServer.releaseAtom(ct);

        calServer.setInstrument(Xmm::RGS2);
        //calServer.state()->mode()->set(Xmm::SPECTROSCOPY); // order=1 !
        calServer.state()->mode()->set(Xmm::HIGH_EVENT_RATE); // order=1 !

        ct = calServer.getAtom(ct);
        ngroups = ct->nGroups();
        ranges = ct->ranges();
        resolution = ct->resolution();
        cout<<"RGS1....."<<endl;
        cout<<"NGRP: "<<ngroups<<" Range[2]: "<<ranges[1]
            <<" RES: "<<resolution[10]<<" "<<resolution[100]<<endl;

        std::vector<short> lamRange = ct->lambda_ranges();
        cout<<"Lam Range: "<<lamRange[0]<<" "<<lamRange[1]<<" "<<lamRange[2]<<" "<<lamRange[3]<<endl;
        std::vector<short> betRange = ct->beta_ranges();

        cout<<"BETA  Range: "<<betRange[0]<<" "<<betRange[1]<<" "<<betRange[2]<<" "<<betRange[3]<<endl;

        gsmin = ct->gainSlopeMin();
        gsmax = ct->gainSlopeMax();
        gomin = ct->gainOffsetMin();
        gomax = ct->gainOffsetMax();

        cout<<"GAIN: "<<gsmin<<" "<<gsmax<<" "<<gomin<<" "<<gomax<<endl;

	return 0;
}


