!
!   sky2pix.f90  --- equivalent of corresponding C++ test with same name
!
!   DESCRIPTION:
!       Project given sky position onto CHIPCOORD frame
!
program sky2pix

use cal             ! use the Calibration Access Layer
use caloaldefs
use errorhandling

    implicit none
    type(BoresightT)                              :: boresight
    type(SpacecraftAttitudeType)                  :: scAtt
    real(kind=double), dimension(:), pointer      :: theta => null(), phi => null(),&
                                                     x => null(), y => null(), z => null()
    real(kind=double), dimension(:), pointer      :: RchipX => null(), RchipY => null()
    integer(int16), dimension(:), pointer         :: chipX => null(), chipY => null()
    integer(int8), dimension(:), pointer          :: ccds => null()
    type(EquatorialDirectionType), dimension(0:1) :: srcDirs
    integer                                       :: i
    real(kind=double)                             :: PI, RAD_TO_DEG, DEG_TO_RAD

    PI = acos(-1.)
    RAD_TO_DEG = 180./PI
    DEG_TO_RAD = 1./RAD_TO_DEG

    call CAL_setState(EMOS1)
    boresight = CAL_getBoresight(0._double)
    scAtt%ra = 0._double;
    scAtt%dec = 0._double;
    scAtt%apos = 0._double;
    call CAL_withSacCoordOrientation(boresight, scAtt)

    !
    ! define two source locations;
    !
    srcDirs(0)%ra = 0.
    srcDirs(0)%dec = 0. ! along STR viewing direction
    srcDirs(1)%ra = 20./3600. * DEG_TO_RAD
    srcDirs(1)%dec = 30./3600.* DEG_TO_RAD ! 20"/30" off STR viewing direction

    call CAL_projectOntoTelCoord(boresight, srcDirs, theta, phi);

    !   conversion to CHIPCOORD
    call CAL_telCoordToCamCoord2(theta, phi, x, y, z)
    call CAL_camCoord2ToCamCoord1(x, y, z, x, y, z)

    call CAL_camCoord1ToChipCoord(x, y, z, chipX, chipY, ccds)

    if (ccds(0) == CCDNONE .or. ccds(1) == CCDNONE) &
        call error('sky2pix', 'Position not on any CCD')
    write(*, *) 'src - ra/dec["/"] - theta/phi["/deg] - chipX/chipY'
    do i=0, size(srcDirs)-1
        write(*, '(I2,1X,F5.1,1X,F5.1,1X,F8.3,1X,F8.3,1X,I3,1X,I3)') &
        i, srcDirs(i)%ra*RAD_TO_DEG*3600., srcDirs(i)%dec*RAD_TO_DEG*3600., &
        theta(i), phi(i)*RAD_TO_DEG, chipX(i), chipY(i)
    enddo

    ! if (chipX(0) /= 236 .or. chipX(1) /= 254 .or. &
    !  chipY(0) /= 237 .or. chipY(1) /= 265) &
    !    call error('sky2pix', 'Incorrect pixel numbers')

    ! Test the real chip coord conversion
    call CAL_camCoord1ToChipRealCoord(x, y, z, RchipX, RchipY, ccds)
    do i=0, size(srcDirs)-1
        write(*, '(I2,1X,F5.1,1X,F5.1,1X,F8.3,1X,F8.3,1X,F7.3,1X,F7.3)') &
        i, srcDirs(i)%ra*RAD_TO_DEG*3600., srcDirs(i)%dec*RAD_TO_DEG*3600., &
        theta(i), phi(i)*RAD_TO_DEG, RchipX(i), RchipY(i)
    enddo

    call CAL_releaseMemory(ccds)
    call CAL_releaseMemory(theta, phi)
    call CAL_releaseMemory(x, y, z)
    call CAL_releaseMemory(chipX, chipY)

    call message(AppMsg, Verbose, "all tests passed")
end program
