//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	CalState.cc	--- implementation of classes in CalState.h
//
//	DESCRIPTION:
//		Implementation of classes in CalState.h
//
//	CHANGE HISTORY:
//		UL, 1999-03-24: 1.0.0: - skeleton
//		UL, 1999-04-19: 1.1.0: - minor bug fix in operator<<
//		UL, 1999-08-12: 1.2.0: - bug fix in operator>>
//
//	AUTHOR:
//		U. Lammers, Wed Mar 24 14:29:44 MET 1999
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /sasbuild/sas_git_repo/cvs_copy/sasdev/sas/packages/cal/src/CalState.cc,v 1.15 2003/10/03 14:15:41 sasbuild Exp $
//

#include "CalState.h"		//	what we have to implement

using namespace std;

static const bool _boolv[] = { false, true };
const vector<bool> boolChoices(_boolv, _boolv+NUM_OF(_boolv));

ostream &operator<<(ostream &os, const CalState &state)
{
	#define PRINTVAR(var)				\
		if (state.var()->isActive())	\
			os<<state.var()->get();		\
		else							\
			os<<"*inactive*"

	os<<"   CCD chip ID            : "; PRINTVAR(ccd); os<<endl<<
		"   CCD readout node       : "; PRINTVAR(node); os<<endl<<
		"   mode                   : "; PRINTVAR(mode); os<<endl<<
		"   filter                 : "; PRINTVAR(filter); os<<endl<<
		"   temperature            : "; PRINTVAR(temperature)<<" "<<
				(state.temperature()->isActive() ?
				 state.temperature()->unit() : ""); os<<endl<<
		"   temperature camera     : "; PRINTVAR(temperatureCamera)<<" "<<
				(state.temperatureCamera()->isActive() ?
				 state.temperatureCamera()->unit() : ""); os<<endl<<
		"   temperature tracking   : "; PRINTVAR(temperatureTracking);
			os<<endl<<
		"   exposure start time    : "; PRINTVAR(exposureStartTime);
			os<<endl<<
		"   exposure duration      : "; PRINTVAR(exposureDuration);
			os<<endl<<
	    "   accuracy level         : "; PRINTVAR(accuracyLevel); os<<endl<<
		"   auxiliary parameter    : "; PRINTVAR(auxiliaryParameter);
			os<<endl<<
		"   randomize              : "; PRINTVAR(randomize); os<<endl<<
		"   on-chip-binning factor : "; PRINTVAR(ocb);

	#undef GETVAR

	return os;
} // operator<<
