//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	FWCDataServer.h --- Cal atom to return Filter Wheel Closed data
//
//	DESCRIPTION:
//
//	CHANGE HISTORY:
//		RDS, 2016-09-26: 1.0: - original
//
//	AUTHOR:
//		R. Saxton
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
#ifndef FWC_H
#define FWC_H

#include "Ccf.h"
#include "CalAtomsBase.h"

#include <vector>
#include <map>

// The structure of exposure time v revolution
typedef struct {
   vector<int> rev;
   vector<double> tstart;
   vector<double> tstop;
   vector<float> exptime;
   vector<short> ccd;
   vector<unsigned> nflag;
} FWCexptime;


// FWC event class
class FWCevent
{
  public:

  /* Constructor */
  FWCevent(double time, short rawx, short rawy, short detx, short dety, 
           short pi, int flag, unsigned pattern, unsigned ccd, 
           float weight, int rev);

  /* Destructor */
  ~FWCevent();

  /* Accessor methods */
  double time() { return _time; }
  short rawx() {return _rawx;}
  short rawy() {return _rawy;}
  short detx() {return _detx;}
  short dety() {return _dety;}
  short pi() {return _pi;}
  int flag() {return _flag;}
  unsigned pattern() {return _pattern;}
  unsigned ccd() {return _ccd;}
  float weight() {return _weight;}
  int rev() {return _rev;}
  void setTime(double time) { _time = time; }

  private:

  double _time;
  float _weight;
  short _rawx, _rawy, _detx, _dety, _pi;
  int _flag,_rev;
  unsigned _pattern,_ccd;

};

//
//	---( mode parameters )------------------------------------------------
//
class FWCDataServer : public CalAtom,
        public virtual CalChild<CalAtomCollection<FWCDataServer> > { 
public:

	// Constructor
	FWCDataServer(  multimap<const pair<int,unsigned>,
                                           FWCevent> fwcevents,
                        FWCexptime etime,
                        CalAtomCollection<FWCDataServer> *parent=0);

	static unsigned id() { return Ccf::FWC; }

        // Methods
        FWCexptime exptime() const { return _et; } // return exptime struct

        // Return requested events for the revolution, CCD pairs
        vector<FWCevent> getEvents(multimap<int,unsigned> revCcd);

private:

        FWCexptime _et; // exposure time v rev structure

        // A map containing all the Filter Wheel Closed events indexed
        // on Revolution,ccd combination
        multimap<const pair<int,unsigned>, FWCevent> _fwcevents;
};


#endif

