//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	OmGrismDataServer --- class to provide OM Grism data from CCF
//
//	DESCRIPTION:
//
//	CHANGE HISTORY:
//		UL/RDS, 2003-10-21: 1.0.0: - initial version
//
//	AUTHOR:
//		U. Lammers (UL), R. Saxton, Tue Oct 21 09:36:22 GMT 2003
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//		[2]: Calibration Access and Data Handbook, XMM instrument team
//
//	$Header: /sasbuild/sas_git_repo/cvs_copy/sasdev/sas/packages/cal/src/OmGrismDataServer.h,v 1.1 2003/10/24 15:29:59 rsaxton Exp $
//
#ifndef OM_GRISM_DATA_SERVER
#define OM_GRISM_DATA_SERVER

#include "Ccf.h"
#include "CalChild.h"
#include "CalAtomsBase.h"

//
//	---( OmGrismDataServer )-------------------------------------------------
//
class OmGrismDataServer : public CalAtom,
	  public virtual CalChild<CalAtomCollection<OmGrismDataServer> > {
public:
	OmGrismDataServer(const CcfConstituentTable &flux,
					  const CcfConstituentTable &wavelength,
					CalAtomCollection<OmGrismDataServer> *parent = 0);
		//
		//	PURPOSE:
		//		Construct OmGrismDataServer object.
		//
		//	ARGUMENTS:
		//		flux:	reference to CCF table 'FLUX_GRISM[1|2]'
		//		wavelength:
		//				reference to CCF table 'WAVELENGTH_GRISM[1|2]'
		//		parent:	pointer to parent of this object
		//


	static unsigned id() { return Ccf::GrismData; }
		//
		//	PURPOSE:
		//		Return a uniue ID which for mapping Cal atoms onto
		//		CCF constituents
		//


	
	struct ISF {
		std::vector<double> wavelength,
							data,
							error;
	};
	const OmGrismDataServer::ISF &isfData() const { return _isf; }
	const std::vector<double> &wavelength() const { return _wavelength; }


	virtual void dump(std::ostream &os);
		//
		//	PURPOSE:
		//		Dump data members to an ostream
		//
		//	ARGUMENTS:
		//		In:
		//			os:	stream to print on
		//


	virtual ~OmGrismDataServer();
		//
		//	PURPOSE:
		//		Destruct OmGrismDataServer  object
		//

private:
	//	data members
    ISF	_isf;
	std::vector<double> _wavelength;
};

#endif
