//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	RgsCoolPixDataServer.h --- classes related to bad pixels
//
//	DESCRIPTION:
//
//	CHANGE HISTORY:
//		RDS, 2006-03-31: 1.0.0: - first version from BadPixelDataServer.h
//
//	AUTHOR:
//		R. Saxton
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /sasbuild/sas_git_repo/cvs_copy/sasdev/sas/packages/cal/src/RgsCoolPixDataServer.h,v 1.1 2006/04/03 15:56:08 rsaxton Exp $
//

#ifndef RGS_COOLPIX_DATA_SERVER_H
#define RGS_COOLPIX_DATA_SERVER_H

#include "Ccf.h"
#include "CalAtomsBase.h"
#include "BadPixelMap.h"
#include "BadPixelDataServer.h"

#include <vector>

class RgsCoolPixDataServer : public CalAtom,
	public virtual CalChild<CalAtomCollection<RgsCoolPixDataServer> > {
public:
	RgsCoolPixDataServer(const string &bptCode,
					   CalAtomCollection<RgsCoolPixDataServer> *parent = 0);
		//
		//	PURPOSE:
		//		Instantiate rgs cool pixel data server object
		//


	static unsigned id() { return Ccf::CoolPix; }
		//
		//	PURPOSE:
		//		Return ID of CalAtom
		//

	static const string INVALID_BAD_PIXEL_TABLE_CODE;
	const string &badPixelTableCode() const { return _bptCode; }
		//
		//	PURPOSE:
		//		Return Bad-Pixel-Table code read from attribute
		//		*BADPIX*:BADPIX%BPT_CODE; returns
		//		RgsCoolPixDataServer::INVALID_BPT_CODE if not present
		//		


	BadPixelMap map() const;
		//
		//	PURPOSE:
		//		Obtain the list of bad pixels applicable for current
		//		instrument mode.
		//


	~RgsCoolPixDataServer();
		//
		//	PURPOSE:
		//		Destroy object constructed with above constructor(s).
		//

private:
	friend class CalAtomCollection<RgsCoolPixDataServer>;

	typedef struct {
		PixelLocation			loc;
		BadPixel				bp;
		std::vector<short>		modena;
	} LocBadPixModeType;
	std::vector<LocBadPixModeType>	_badPixels;
	std::string						_bptCode;
};

#endif

